/*****************************************************************************\
 * Astro
 *
 * Astro     defines misc. handy constants & fns
 *
 * author: mark huss (mark@mhuss.com)
 *
\*****************************************************************************/

#include "Astro.h"

// * * * * * Generic Handy Constants and Conversions * * * * *

// We do the static const member initializtion here the "old-fashioned" way to
// get around problems with some compilers...

// day and time constants
const double Astro::HOURS_PER_DAY       = 24.;
const double Astro::DAYS_PER_HOUR       = 1./HOURS_PER_DAY;   // 1 hr as a fractional day
const double Astro::SECONDS_PER_MINUTE  = 60.;
const double Astro::MINUTES_PER_HOUR    = 60.;
const double Astro::SECONDS_PER_HOUR    = SECONDS_PER_MINUTE * MINUTES_PER_HOUR;
const double Astro::MINUTES_PER_DAY     = HOURS_PER_DAY * MINUTES_PER_HOUR;
const double Astro::SECONDS_PER_DAY     = MINUTES_PER_DAY * SECONDS_PER_MINUTE;

const int    Astro::IHOURS_PER_DAY      = int(HOURS_PER_DAY);
const int    Astro::ISECONDS_PER_MINUTE = int(SECONDS_PER_MINUTE);
const int    Astro::IMINUTES_PER_HOUR   = int(MINUTES_PER_HOUR);
const int    Astro::ISECONDS_PER_HOUR   = int(SECONDS_PER_HOUR);

// oft-used mathematical/circle constants
const double Astro::PI                  = 3.14159265358979323846;
const double Astro::TWO_PI              = 6.28318530717958647692;
const double Astro::PI_OVER_TWO         = 1.57079632679489661923;
const double Astro::TWO_OVER_PI         = 0.63661977236758134308;

const double Astro::RAD_PER_CIRCLE      = TWO_PI;
const double Astro::DEG_PER_CIRCLE      = 360.;
const double Astro::MINUTES_PER_DEGREE  = 60.;
const double Astro::SECONDS_PER_DEGREE  = MINUTES_PER_DEGREE * SECONDS_PER_MINUTE;
const double Astro::RADS_PER_DEGREE     = RAD_PER_CIRCLE / DEG_PER_CIRCLE;

// JD-related constants
const double Astro::DAYS_PER_CENTURY    = 36525.;
const double Astro::DAYS_PER_MILLENIUM  = 365250.;
const double Astro::JD_DIFF             = 0.5;
const double Astro::J2000               = 2451545.0;

// misc.
const double Astro::ROUND   = 0.5;
const double Astro::INVALID = -1.0;

